# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'spotii.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(480, 272)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setWindowTitle("MainWindow")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.title = QtWidgets.QWidget(self.centralwidget)
        self.title.setGeometry(QtCore.QRect(0, 0, 480, 49))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.title.sizePolicy().hasHeightForWidth())
        self.title.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(1)
        self.title.setFont(font)
        self.title.setStyleSheet("background-image: url(:/title_background/png/title/rectangle.png);")
        self.title.setInputMethodHints(QtCore.Qt.ImhNone)
        self.title.setObjectName("title")
        self.gridLayout = QtWidgets.QGridLayout(self.title)
        self.gridLayout.setContentsMargins(0, 0, 5, 0)
        self.gridLayout.setHorizontalSpacing(5)
        self.gridLayout.setObjectName("gridLayout")
        self.volume = MyToolButton(self.title)
        self.volume.setEnabled(True)
        self.volume.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
        self.volume.setInputMethodHints(QtCore.Qt.ImhNone)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/sound/png/title/spot-icons-sound-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon.addPixmap(QtGui.QPixmap(":/sound/png/title/spot-icons-sound-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.volume.setIcon(icon)
        self.volume.setIconSize(QtCore.QSize(24, 18))
        self.volume.setCheckable(True)
        self.volume.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.volume.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.volume.setObjectName("volume")
        self.gridLayout.addWidget(self.volume, 0, 6, 1, 1)
        self.wifi = MyToolButton(self.title)
        self.wifi.setEnabled(True)
        self.wifi.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
        self.wifi.setInputMethodHints(QtCore.Qt.ImhNone)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon1.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.wifi.setIcon(icon1)
        self.wifi.setIconSize(QtCore.QSize(24, 18))
        self.wifi.setCheckable(True)
        self.wifi.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.wifi.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.wifi.setObjectName("wifi")
        self.gridLayout.addWidget(self.wifi, 0, 4, 1, 1)
        self.logo = QtWidgets.QLabel(self.title)
        self.logo.setText("")
        self.logo.setPixmap(QtGui.QPixmap(":/logo/png/title/logo.png"))
        self.logo.setScaledContents(True)
        self.logo.setObjectName("logo")
        self.gridLayout.addWidget(self.logo, 0, 0, 1, 1)
        self.test_mode = QtWidgets.QToolButton(self.title)
        self.test_mode.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.test_mode.sizePolicy().hasHeightForWidth())
        self.test_mode.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(8)
        font.setBold(True)
        font.setWeight(75)
        font.setKerning(False)
        self.test_mode.setFont(font)
        self.test_mode.setStyleSheet("QToolButton{background-color: transparent; border:0; color : rgb(248,176,0)}")
        self.test_mode.setInputMethodHints(QtCore.Qt.ImhNone)
        self.test_mode.setIconSize(QtCore.QSize(24, 18))
        self.test_mode.setCheckable(True)
        self.test_mode.setChecked(False)
        self.test_mode.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.test_mode.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.test_mode.setObjectName("test_mode")
        self.gridLayout.addWidget(self.test_mode, 0, 10, 1, 1)
        self.help = MyToolButton(self.title)
        self.help.setEnabled(True)
        font = QtGui.QFont()
        font.setKerning(True)
        self.help.setFont(font)
        self.help.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
        self.help.setInputMethodHints(QtCore.Qt.ImhNone)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/help/png/title/spot-icons-help-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon2.addPixmap(QtGui.QPixmap(":/help/png/title/spot-icons-help-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.help.setIcon(icon2)
        self.help.setIconSize(QtCore.QSize(24, 18))
        self.help.setCheckable(True)
        self.help.setPopupMode(QtWidgets.QToolButton.DelayedPopup)
        self.help.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.help.setObjectName("help")
        self.gridLayout.addWidget(self.help, 0, 3, 1, 1)
        self.chip_mode = QtWidgets.QLabel(self.title)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.chip_mode.sizePolicy().hasHeightForWidth())
        self.chip_mode.setSizePolicy(sizePolicy)
        self.chip_mode.setMinimumSize(QtCore.QSize(45, 0))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(8)
        font.setBold(True)
        font.setWeight(75)
        self.chip_mode.setFont(font)
        self.chip_mode.setStyleSheet("QLabel{background-color: transparent; border:0; color : rgb(248,176,0)}")
        self.chip_mode.setAlignment(QtCore.Qt.AlignCenter)
        self.chip_mode.setWordWrap(True)
        self.chip_mode.setObjectName("chip_mode")
        self.gridLayout.addWidget(self.chip_mode, 0, 2, 1, 1)
        self.profile_icon = MyToolButton(self.title)
        self.profile_icon.setEnabled(True)
        self.profile_icon.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
        self.profile_icon.setInputMethodHints(QtCore.Qt.ImhNone)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/profile/png/title/spot-icons-profile-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon3.addPixmap(QtGui.QPixmap(":/profile/png/title/spot-icons-profile-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.profile_icon.setIcon(icon3)
        self.profile_icon.setIconSize(QtCore.QSize(24, 18))
        self.profile_icon.setCheckable(True)
        self.profile_icon.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.profile_icon.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.profile_icon.setObjectName("profile_icon")
        self.gridLayout.addWidget(self.profile_icon, 0, 9, 1, 1)
        self.setting = MyToolButton(self.title)
        self.setting.setEnabled(True)
        self.setting.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
        self.setting.setInputMethodHints(QtCore.Qt.ImhNone)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/setting/png/title/spot-icons-settings-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon4.addPixmap(QtGui.QPixmap(":/setting/png/title/spot-icons-settings-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.setting.setIcon(icon4)
        self.setting.setIconSize(QtCore.QSize(24, 18))
        self.setting.setCheckable(True)
        self.setting.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.setting.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.setting.setObjectName("setting")
        self.gridLayout.addWidget(self.setting, 0, 8, 1, 1)
        self.time_label = QtWidgets.QLabel(self.title)
        font = QtGui.QFont()
        font.setFamily("Roboto Black")
        font.setPointSize(14)
        self.time_label.setFont(font)
        self.time_label.setStyleSheet(".QLabel{background-color: transparent; border:0; color :white}")
        self.time_label.setObjectName("time_label")
        self.gridLayout.addWidget(self.time_label, 0, 1, 1, 1)
        self.slot_1 = MyStackedWidget(self.centralwidget)
        self.slot_1.setGeometry(QtCore.QRect(0, 49, 96, 224))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slot_1.sizePolicy().hasHeightForWidth())
        self.slot_1.setSizePolicy(sizePolicy)
        self.slot_1.setStyleSheet("")
        self.slot_1.setObjectName("slot_1")
        self.slot_2 = MyStackedWidget(self.centralwidget)
        self.slot_2.setGeometry(QtCore.QRect(96, 49, 96, 224))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slot_2.sizePolicy().hasHeightForWidth())
        self.slot_2.setSizePolicy(sizePolicy)
        self.slot_2.setStyleSheet("")
        self.slot_2.setObjectName("slot_2")
        self.slot_3 = MyStackedWidget(self.centralwidget)
        self.slot_3.setGeometry(QtCore.QRect(192, 49, 96, 224))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slot_3.sizePolicy().hasHeightForWidth())
        self.slot_3.setSizePolicy(sizePolicy)
        self.slot_3.setStyleSheet("")
        self.slot_3.setObjectName("slot_3")
        self.slot_4 = MyStackedWidget(self.centralwidget)
        self.slot_4.setGeometry(QtCore.QRect(288, 49, 96, 224))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slot_4.sizePolicy().hasHeightForWidth())
        self.slot_4.setSizePolicy(sizePolicy)
        self.slot_4.setStyleSheet("")
        self.slot_4.setObjectName("slot_4")
        self.slot_5 = MyStackedWidget(self.centralwidget)
        self.slot_5.setGeometry(QtCore.QRect(384, 49, 96, 224))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slot_5.sizePolicy().hasHeightForWidth())
        self.slot_5.setSizePolicy(sizePolicy)
        self.slot_5.setStyleSheet("")
        self.slot_5.setObjectName("slot_5")
        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)
        self.slot_1.setCurrentIndex(-1)
        self.slot_2.setCurrentIndex(-1)
        self.slot_3.setCurrentIndex(-1)
        self.slot_4.setCurrentIndex(-1)
        self.slot_5.setCurrentIndex(-1)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        self.test_mode.setText(_translate("MainWindow", "SPEED"))
        self.chip_mode.setText(_translate("MainWindow", "AUTO MODE"))
        self.time_label.setText(_translate("MainWindow", "00:00"))
from MyStackedWidget import MyStackedWidget
from MyToolButton import MyToolButton
import title_rc
